# This is a generated file! Please edit source .ksy file and use kaitai-struct-compiler to rebuild

from pkg_resources import parse_version
import kaitaistruct
from kaitaistruct import KaitaiStruct, KaitaiStream, BytesIO


if parse_version(kaitaistruct.__version__) < parse_version('0.9'):
    raise Exception("Incompatible Kaitai Struct Python API: 0.9 or later is required, but you have %s" % (kaitaistruct.__version__))

class Bisonsat(KaitaiStruct):
    """:field dest_callsign: ax25_frame.ax25_header.dest_callsign_raw.callsign_ror.callsign
    :field src_callsign: ax25_frame.ax25_header.src_callsign_raw.callsign_ror.callsign
    :field src_ssid: ax25_frame.ax25_header.src_ssid_raw.ssid
    :field dest_ssid: ax25_frame.ax25_header.dest_ssid_raw.ssid
    :field rpt_callsign: ax25_frame.ax25_header.repeater.rpt_instance[0].rpt_callsign_raw.callsign_ror.callsign
    :field ctl: ax25_frame.ax25_header.ctl
    :field pid: ax25_frame.payload.pid
    :field rtc_time_year: ax25_frame.payload.ax25_info.rtc_time_year
    :field rtc_time_month: ax25_frame.payload.ax25_info.rtc_time_month
    :field rtc_time_day: ax25_frame.payload.ax25_info.rtc_time_day
    :field rtc_time_hour: ax25_frame.payload.ax25_info.rtc_time_hour
    :field rtc_time_minutes: ax25_frame.payload.ax25_info.rtc_time_minutes
    :field rtc_time_seconds: ax25_frame.payload.ax25_info.rtc_time_seconds
    :field rtc_time_th: ax25_frame.payload.ax25_info.rtc_time_th
    :field os_ticks: ax25_frame.payload.ax25_info.os_ticks
    :field last_cmd_1: ax25_frame.payload.ax25_info.last_cmd_1
    :field last_cmd_2: ax25_frame.payload.ax25_info.last_cmd_2
    :field cmd_queue_length: ax25_frame.payload.ax25_info.cmd_queue_length
    :field filename_jpeg: ax25_frame.payload.ax25_info.filename_jpeg
    :field filename_raw: ax25_frame.payload.ax25_info.filename_raw
    :field cdh_reset_events: ax25_frame.payload.ax25_info.cdh_reset_events
    :field y_plus_current: ax25_frame.payload.ax25_info.y_plus_current
    :field y_plus_temperature: ax25_frame.payload.ax25_info.y_plus_temperature
    :field y_pair_voltage: ax25_frame.payload.ax25_info.y_pair_voltage
    :field x_minus_current: ax25_frame.payload.ax25_info.x_minus_current
    :field x_minus_temperature: ax25_frame.payload.ax25_info.x_minus_temperature
    :field x_pair_voltage: ax25_frame.payload.ax25_info.x_pair_voltage
    :field x_plus_current: ax25_frame.payload.ax25_info.x_plus_current
    :field x_plus_temperature: ax25_frame.payload.ax25_info.x_plus_temperature
    :field z_pair_voltage: ax25_frame.payload.ax25_info.z_pair_voltage
    :field z_plus__current: ax25_frame.payload.ax25_info.z_plus__current
    :field z_plus_temperature: ax25_frame.payload.ax25_info.z_plus_temperature
    :field y_minus_current: ax25_frame.payload.ax25_info.y_minus_current
    :field y_minus_temperature: ax25_frame.payload.ax25_info.y_minus_temperature
    :field battery_current: ax25_frame.payload.ax25_info.battery_current
    :field battery1_temperature: ax25_frame.payload.ax25_info.battery1_temperature
    :field battery1_full_voltage: ax25_frame.payload.ax25_info.battery1_full_voltage
    :field battery1_current_direction: ax25_frame.payload.ax25_info.battery1_current_direction
    :field battery1_current: ax25_frame.payload.ax25_info.battery1_current
    :field battery0_temperature: ax25_frame.payload.ax25_info.battery0_temperature
    :field battery0_full_voltage: ax25_frame.payload.ax25_info.battery0_full_voltage
    :field bus_current_5v: ax25_frame.payload.ax25_info.bus_current_5v
    :field bus_current_3v3: ax25_frame.payload.ax25_info.bus_current_3v3
    :field battery0_current_direction: ax25_frame.payload.ax25_info.battery0_current_direction
    :field battery0_current: ax25_frame.payload.ax25_info.battery0_current
    :field z_minus_temperature: ax25_frame.payload.ax25_info.z_minus_temperature
    :field z_minus_current: ax25_frame.payload.ax25_info.z_minus_current
    :field hmb_accelx: ax25_frame.payload.ax25_info.hmb_accelx
    :field hmb_accely: ax25_frame.payload.ax25_info.hmb_accely
    :field hmb_accelz: ax25_frame.payload.ax25_info.hmb_accelz
    :field hmb_temperature: ax25_frame.payload.ax25_info.hmb_temperature
    :field hmb_gyrox: ax25_frame.payload.ax25_info.hmb_gyrox
    :field hmb_gyroy: ax25_frame.payload.ax25_info.hmb_gyroy
    :field hmb_gyroz: ax25_frame.payload.ax25_info.hmb_gyroz
    :field hmb_magx: ax25_frame.payload.ax25_info.hmb_magx
    :field hmb_magy: ax25_frame.payload.ax25_info.hmb_magy
    :field hmb_magz: ax25_frame.payload.ax25_info.hmb_magz
    :field task_rst_status: ax25_frame.payload.ax25_info.task_rst_status
    :field task_antenna_deploy_status: ax25_frame.payload.ax25_info.task_antenna_deploy_status
    :field task_telemetry_gather_status: ax25_frame.payload.ax25_info.task_telemetry_gather_status
    :field task_image_capture_status: ax25_frame.payload.ax25_info.task_image_capture_status
    :field task_jpeg_status: ax25_frame.payload.ax25_info.task_jpeg_status
    :field task_com_receive_status: ax25_frame.payload.ax25_info.task_com_receive_status
    :field task_cmd_decoder_status: ax25_frame.payload.ax25_info.task_cmd_decoder_status
    :field task_bisonsat_cmd_decoder_status: ax25_frame.payload.ax25_info.task_bisonsat_cmd_decoder_status
    :field task_tranmit_image_status: ax25_frame.payload.ax25_info.task_tranmit_image_status
    :field cdh_wdt_events: ax25_frame.payload.ax25_info.cdh_wdt_events
    :field eps_status: ax25_frame.payload.ax25_info.eps_status
    
    .. seealso::
       Source - http://cubesat.skc.edu/beacon-decoding-information/
    """
    def __init__(self, _io, _parent=None, _root=None):
        self._io = _io
        self._parent = _parent
        self._root = _root if _root else self
        self._read()

    def _read(self):
        self.ax25_frame = Bisonsat.Ax25Frame(self._io, self, self._root)

    class Ax25Frame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ax25_header = Bisonsat.Ax25Header(self._io, self, self._root)
            _on = (self.ax25_header.ctl & 19)
            if _on == 0:
                self.payload = Bisonsat.IFrame(self._io, self, self._root)
            elif _on == 3:
                self.payload = Bisonsat.UiFrame(self._io, self, self._root)
            elif _on == 19:
                self.payload = Bisonsat.UiFrame(self._io, self, self._root)
            elif _on == 16:
                self.payload = Bisonsat.IFrame(self._io, self, self._root)
            elif _on == 18:
                self.payload = Bisonsat.IFrame(self._io, self, self._root)
            elif _on == 2:
                self.payload = Bisonsat.IFrame(self._io, self, self._root)


    class Ax25Header(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.dest_callsign_raw = Bisonsat.CallsignRaw(self._io, self, self._root)
            self.dest_ssid_raw = Bisonsat.SsidMask(self._io, self, self._root)
            self.src_callsign_raw = Bisonsat.CallsignRaw(self._io, self, self._root)
            self.src_ssid_raw = Bisonsat.SsidMask(self._io, self, self._root)
            if (self.src_ssid_raw.ssid_mask & 1) == 0:
                self.repeater = Bisonsat.Repeater(self._io, self, self._root)

            self.ctl = self._io.read_u1()


    class UiFrame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pid = self._io.read_u1()
            self._raw_ax25_info = self._io.read_bytes_full()
            _io__raw_ax25_info = KaitaiStream(BytesIO(self._raw_ax25_info))
            self.ax25_info = Bisonsat.Ax25InfoData(_io__raw_ax25_info, self, self._root)


    class Callsign(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.callsign = (self._io.read_bytes(6)).decode(u"ASCII")


    class IFrame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pid = self._io.read_u1()
            self._raw_ax25_info = self._io.read_bytes_full()
            _io__raw_ax25_info = KaitaiStream(BytesIO(self._raw_ax25_info))
            self.ax25_info = Bisonsat.Ax25InfoData(_io__raw_ax25_info, self, self._root)


    class SsidMask(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ssid_mask = self._io.read_u1()

        @property
        def ssid(self):
            if hasattr(self, '_m_ssid'):
                return self._m_ssid if hasattr(self, '_m_ssid') else None

            self._m_ssid = ((self.ssid_mask & 15) >> 1)
            return self._m_ssid if hasattr(self, '_m_ssid') else None


    class Repeaters(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rpt_callsign_raw = Bisonsat.CallsignRaw(self._io, self, self._root)
            self.rpt_ssid_raw = Bisonsat.SsidMask(self._io, self, self._root)


    class Repeater(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rpt_instance = []
            i = 0
            while True:
                _ = Bisonsat.Repeaters(self._io, self, self._root)
                self.rpt_instance.append(_)
                if (_.rpt_ssid_raw.ssid_mask & 1) == 1:
                    break
                i += 1


    class CallsignRaw(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self._raw__raw_callsign_ror = self._io.read_bytes(6)
            self._raw_callsign_ror = KaitaiStream.process_rotate_left(self._raw__raw_callsign_ror, 8 - (1), 1)
            _io__raw_callsign_ror = KaitaiStream(BytesIO(self._raw_callsign_ror))
            self.callsign_ror = Bisonsat.Callsign(_io__raw_callsign_ror, self, self._root)


    class Ax25InfoData(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.offset = (self._io.read_bytes(7)).decode(u"ASCII")
            self.preamble = (self._io.read_bytes(3)).decode(u"ASCII")
            self.call_sign = (self._io.read_bytes(6)).decode(u"ASCII")
            self.rtc_time_year = self._io.read_u1()
            self.rtc_time_month = self._io.read_u1()
            self.rtc_time_day = self._io.read_u1()
            self.rtc_time_hour = self._io.read_u1()
            self.rtc_time_minutes = self._io.read_u1()
            self.rtc_time_seconds = self._io.read_u1()
            self.rtc_time_th = self._io.read_u1()
            self.os_ticks = self._io.read_u4le()
            self.last_cmd_1 = self._io.read_u1()
            self.last_cmd_2 = self._io.read_u1()
            self.cmd_queue_length = self._io.read_u1()
            self.filename_jpeg = (self._io.read_bytes(8)).decode(u"ASCII")
            self.filename_raw = (self._io.read_bytes(8)).decode(u"ASCII")
            self.cdh_reset_events = self._io.read_u1()
            self.y_plus_current = self._io.read_u2le()
            self.y_plus_temperature = self._io.read_u2le()
            self.y_pair_voltage = self._io.read_u2le()
            self.x_minus_current = self._io.read_u2le()
            self.x_minus_temperature = self._io.read_u2le()
            self.x_pair_voltage = self._io.read_u2le()
            self.x_plus_current = self._io.read_u2le()
            self.x_plus_temperature = self._io.read_u2le()
            self.z_pair_voltage = self._io.read_u2le()
            self.z_plus__current = self._io.read_u2le()
            self.z_plus_temperature = self._io.read_u2le()
            self.y_minus_current = self._io.read_u2le()
            self.y_minus_temperature = self._io.read_u2le()
            self.battery_current = self._io.read_u2le()
            self.battery1_temperature = self._io.read_u2le()
            self.battery1_full_voltage = self._io.read_u2le()
            self.battery1_current_direction = self._io.read_u2le()
            self.battery1_current = self._io.read_u2le()
            self.battery0_temperature = self._io.read_u2le()
            self.battery0_full_voltage = self._io.read_u2le()
            self.bus_current_5v = self._io.read_u2le()
            self.bus_current_3v3 = self._io.read_u2le()
            self.battery0_current_direction = self._io.read_u2le()
            self.battery0_current = self._io.read_u2le()
            self.z_minus_temperature = self._io.read_u2le()
            self.z_minus_current = self._io.read_u2le()
            self.hmb_accelx = self._io.read_u2le()
            self.hmb_accely = self._io.read_u2le()
            self.hmb_accelz = self._io.read_u2le()
            self.hmb_temperature = self._io.read_u2le()
            self.hmb_gyrox = self._io.read_u2le()
            self.hmb_gyroy = self._io.read_u2le()
            self.hmb_gyroz = self._io.read_u2le()
            self.hmb_magx = self._io.read_u2le()
            self.hmb_magy = self._io.read_u2le()
            self.hmb_magz = self._io.read_u2le()
            self.task_rst_status = self._io.read_u1()
            self.task_antenna_deploy_status = self._io.read_u1()
            self.task_telemetry_gather_status = self._io.read_u1()
            self.task_image_capture_status = self._io.read_u1()
            self.task_jpeg_status = self._io.read_u1()
            self.task_com_receive_status = self._io.read_u1()
            self.task_cmd_decoder_status = self._io.read_u1()
            self.task_bisonsat_cmd_decoder_status = self._io.read_u1()
            self.task_tranmit_image_status = self._io.read_u1()
            self.cdh_wdt_events = self._io.read_u1()
            self.eps_status = self._io.read_u2le()






# This is a generated file! Please edit source .ksy file and use kaitai-struct-compiler to rebuild

from pkg_resources import parse_version
import kaitaistruct
from kaitaistruct import KaitaiStruct, KaitaiStream, BytesIO


if parse_version(kaitaistruct.__version__) < parse_version('0.9'):
    raise Exception("Incompatible Kaitai Struct Python API: 0.9 or later is required, but you have %s" % (kaitaistruct.__version__))

class Picsat(KaitaiStruct):
    """:field dest_callsign: ax25_frame.ax25_header.dest_callsign_raw.callsign_ror.callsign
    :field src_callsign: ax25_frame.ax25_header.src_callsign_raw.callsign_ror.callsign
    :field src_ssid: ax25_frame.ax25_header.src_ssid_raw.ssid
    :field dest_ssid: ax25_frame.ax25_header.dest_ssid_raw.ssid
    :field rpt_callsign: ax25_frame.ax25_header.repeater.rpt_instance[0].rpt_callsign_raw.callsign_ror.callsign
    :field ctl: ax25_frame.ax25_header.ctl
    :field pid: ax25_frame.payload.pid
    :field ccsds_version: ax25_frame.ax25_payload.ax25_info.ccsds_header.ccsds_version
    :field packet_type: ax25_frame.ax25_payload.ax25_info.ccsds_header.packet_type
    :field secondary_header_flag: ax25_frame.ax25_payload.ax25_info.ccsds_header.secondary_header_flag
    :field process_id: ax25_frame.ax25_payload.ax25_info.ccsds_header.process_id
    :field level_flag: ax25_frame.ax25_payload.ax25_info.ccsds_header.level_flag
    :field payload_flag: ax25_frame.ax25_payload.ax25_info.ccsds_header.payload_flag
    :field packet_category: ax25_frame.ax25_payload.ax25_info.ccsds_header.packet_category
    :field sequence_flag: ax25_frame.ax25_payload.ax25_info.ccsds_header.sequence_flag
    :field packet_id: ax25_frame.ax25_payload.ax25_info.ccsds_header.packet_id
    :field data_length: ax25_frame.ax25_payload.ax25_info.ccsds_header.data_length
    :field days_since_ref: ax25_frame.ax25_payload.ax25_info.ccsds_secondary_header.days_since_ref
    :field ms_since_today: ax25_frame.ax25_payload.ax25_info.ccsds_secondary_header.ms_since_today
    :field solar_panel5_error_flag: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.solar_panel5_error_flag
    :field solar_panel4_error_flag: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.solar_panel4_error_flag
    :field solar_panel3_error_flag: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.solar_panel3_error_flag
    :field solar_panel2_error_flag: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.solar_panel2_error_flag
    :field solar_panel1_error_flag: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.solar_panel1_error_flag
    :field i_adcs_get_attitude_error: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.i_adcs_get_attitude_error
    :field i_adcs_get_status_register_error: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.i_adcs_get_status_register_error
    :field fram_enable_error_flag: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.fram_enable_error_flag
    :field ants_b_error_flag: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.ants_b_error_flag
    :field ants_a_error_flag: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.ants_a_error_flag
    :field trxvu_tx_error_flag: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.trxvu_tx_error_flag
    :field trxvu_rx_error_flag: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.trxvu_rx_error_flag
    :field obc_supervisor_error_flag: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.obc_supervisor_error_flag
    :field gom_eps_error_flag: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.gom_eps_error_flag
    :field ant1_undeployed_ants_b_status: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.ant1_undeployed_ants_b_status
    :field ant1_timeout_ants_b_status: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.ant1_timeout_ants_b_status
    :field ant1_deploying_ants_b_status: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.ant1_deploying_ants_b_status
    :field ant2_undeployed_ants_b_status: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.ant2_undeployed_ants_b_status
    :field ant2_timeout_ants_b_status: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.ant2_timeout_ants_b_status
    :field ant2_deploying_ants_b_status: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.ant2_deploying_ants_b_status
    :field ignore_flag_ants_b_status: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.ignore_flag_ants_b_status
    :field ant3_undeployed_ants_b_status: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.ant3_undeployed_ants_b_status
    :field ant3_timeout_ants_b_status: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.ant3_timeout_ants_b_status
    :field ant3_deploying_ants_b_status: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.ant3_deploying_ants_b_status
    :field ant4_undeployed_ants_b_status: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.ant4_undeployed_ants_b_status
    :field ant4_timeout_ants_b_status: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.ant4_timeout_ants_b_status
    :field ant4_deploying_ants_b_status: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.ant4_deploying_ants_b_status
    :field armed_ants_b_status: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.armed_ants_b_status
    :field ant1_undeployed_ants_a_status: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.ant1_undeployed_ants_a_status
    :field ant1_timeout_ants_a_status: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.ant1_timeout_ants_a_status
    :field ant1_deploying_ants_a_status: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.ant1_deploying_ants_a_status
    :field ant2_undeployed_ants_a_status: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.ant2_undeployed_ants_a_status
    :field ant2_timeout_ants_a_status: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.ant2_timeout_ants_a_status
    :field ant2_deploying_ants_a_status: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.ant2_deploying_ants_a_status
    :field ignore_flag_ants_a_status: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.ignore_flag_ants_a_status
    :field ant3_undeployed_ants_a_status: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.ant3_undeployed_ants_a_status
    :field ant3_timeout_ants_a_status: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.ant3_timeout_ants_a_status
    :field ant3_deploying_ants_a_status: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.ant3_deploying_ants_a_status
    :field ant4_undeployed_ants_a_status: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.ant4_undeployed_ants_a_status
    :field ant4_timeout_ants_a_status: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.ant4_timeout_ants_a_status
    :field ant4_deploying_ants_a_status: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.ant4_deploying_ants_a_status
    :field armed_ants_a_status: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.armed_ants_a_status
    :field solar_panel_temp5_zp: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.solar_panel_temp5_zp
    :field solar_panel_temp4_ym: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.solar_panel_temp4_ym
    :field solar_panel_temp3_yp: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.solar_panel_temp3_yp
    :field solar_panel_temp2_xm: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.solar_panel_temp2_xm
    :field solar_panel_temp1_xp: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.solar_panel_temp1_xp
    :field ants_temperature_side_b: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.ants_temperature_side_b
    :field ants_temperature_side_a: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.ants_temperature_side_a
    :field tx_trxvu_hk_current: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.tx_trxvu_hk_current
    :field tx_trxvu_hk_forwardpower: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.tx_trxvu_hk_forwardpower
    :field tx_trxvu_hk_tx_reflectedpower: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.tx_trxvu_hk_tx_reflectedpower
    :field tx_trxvu_hk_pa_temp: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.tx_trxvu_hk_pa_temp
    :field rx_trxvu_hk_pa_temp: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.rx_trxvu_hk_pa_temp
    :field rx_trxvu_hk_board_temp: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.rx_trxvu_hk_board_temp
    :field eps_hk_temp_batt1: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.eps_hk_temp_batt1
    :field eps_hk_temp_batt0: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.eps_hk_temp_batt0
    :field eps_hk_batt_mode: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.eps_hk_batt_mode
    :field eps_h_kv_batt: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.eps_h_kv_batt
    :field eps_hk_boot_cause: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.eps_hk_boot_cause
    :field n_reboots_eps: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.n_reboots_eps
    :field n_reboots_obc: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.n_reboots_obc
    :field quaternion1: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.quaternion1
    :field quaternion2: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.quaternion2
    :field quaternion3: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.quaternion3
    :field quaternion4: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.quaternion4
    :field angular_rate_x: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.angular_rate_x
    :field angular_rate_y: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.angular_rate_y
    :field angular_rate_z: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.angular_rate_z
    :field adcs_stat_flag_hl_op_tgt_cap: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.adcs_stat_flag_hl_op_tgt_cap
    :field adcs_stat_flag_hl_op_tgt_track_fix_wgs84: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.adcs_stat_flag_hl_op_tgt_track_fix_wgs84
    :field adcs_stat_flag_hl_op_tgt_track_nadir: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.adcs_stat_flag_hl_op_tgt_track_nadir
    :field adcs_stat_flag_hl_op_tgt_track: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.adcs_stat_flag_hl_op_tgt_track
    :field adcs_stat_flag_hl_op_tgt_track_const_v: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.adcs_stat_flag_hl_op_tgt_track_const_v
    :field adcs_stat_flag_hl_op_spin: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.adcs_stat_flag_hl_op_spin
    :field adcs_stat_flag_hl_op_sunp: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.adcs_stat_flag_hl_op_sunp
    :field adcs_stat_flag_hl_op_detumbling: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.adcs_stat_flag_hl_op_detumbling
    :field adcs_stat_flag_hl_op_measure: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.adcs_stat_flag_hl_op_measure
    :field adcs_stat_flag_datetime_valid: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.adcs_stat_flag_datetime_valid
    :field adcs_stat_flag_hl_op_safe: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.adcs_stat_flag_hl_op_safe
    :field adcs_stat_flag_hl_op_idle: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.adcs_stat_flag_hl_op_idle
    :field up_time: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.up_time
    :field last_fram_log_fun_err_code: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.last_fram_log_fun_err_code
    :field last_fram_log_line_code: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.last_fram_log_line_code
    :field last_fram_log_file_crc_code: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.last_fram_log_file_crc_code
    :field last_fram_log_counter: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.last_fram_log_counter
    :field average_photon_count: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.average_photon_count
    :field sat_mode: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.sat_mode
    :field tc_sequence_count: ax25_frame.ax25_payload.ax25_info.ccsds_data_section.obc_packet.tc_sequence_count
    """
    def __init__(self, _io, _parent=None, _root=None):
        self._io = _io
        self._parent = _parent
        self._root = _root if _root else self
        self._read()

    def _read(self):
        self.ax25_frame = Picsat.Ax25Frame(self._io, self, self._root)

    class Ax25Frame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ax25_header = Picsat.Ax25Header(self._io, self, self._root)
            _on = (self.ax25_header.ctl & 19)
            if _on == 0:
                self.ax25_payload = Picsat.IFrame(self._io, self, self._root)
            elif _on == 3:
                self.ax25_payload = Picsat.UiFrame(self._io, self, self._root)
            elif _on == 19:
                self.ax25_payload = Picsat.UiFrame(self._io, self, self._root)
            elif _on == 16:
                self.ax25_payload = Picsat.IFrame(self._io, self, self._root)
            elif _on == 18:
                self.ax25_payload = Picsat.IFrame(self._io, self, self._root)
            elif _on == 2:
                self.ax25_payload = Picsat.IFrame(self._io, self, self._root)


    class Ax25Header(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.dest_callsign_raw = Picsat.CallsignRaw(self._io, self, self._root)
            self.dest_ssid_raw = Picsat.SsidMask(self._io, self, self._root)
            self.src_callsign_raw = Picsat.CallsignRaw(self._io, self, self._root)
            self.src_ssid_raw = Picsat.SsidMask(self._io, self, self._root)
            if (self.src_ssid_raw.ssid_mask & 1) == 0:
                self.repeater = Picsat.Repeater(self._io, self, self._root)

            self.ctl = self._io.read_u1()


    class UiFrame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pid = self._io.read_u1()
            self._raw_ax25_info = self._io.read_bytes_full()
            _io__raw_ax25_info = KaitaiStream(BytesIO(self._raw_ax25_info))
            self.ax25_info = Picsat.PicsatCcsdsFrameT(_io__raw_ax25_info, self, self._root)


    class Callsign(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.callsign = (self._io.read_bytes(6)).decode(u"ASCII")
            if not  ((self.callsign == u"PICSAT")) :
                raise kaitaistruct.ValidationNotAnyOfError(self.callsign, self._io, u"/types/callsign/seq/0")


    class CcsdsHeaderT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ccsds_version = self._io.read_bits_int_be(3)
            self.packet_type = self._io.read_bits_int_be(1) != 0
            self.secondary_header_flag = self._io.read_bits_int_be(1) != 0
            self.process_id = self._io.read_bits_int_be(4)
            self.level_flag = self._io.read_bits_int_be(1) != 0
            self.payload_flag = self._io.read_bits_int_be(1) != 0
            self.packet_category = self._io.read_bits_int_be(5)
            self.sequence_flag = self._io.read_bits_int_be(2)
            self.packet_id = self._io.read_bits_int_be(14)
            self.data_length = self._io.read_bits_int_be(16)


    class PicsatCcsdsFrameT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ccsds_header = Picsat.CcsdsHeaderT(self._io, self, self._root)
            if True == self.ccsds_header.secondary_header_flag:
                self.ccsds_secondary_header = Picsat.CcsdsSecondaryHeaderT(self._io, self, self._root)

            if False == self.ccsds_header.payload_flag:
                self.ccsds_data_section = Picsat.ObcPacketT(self._io, self, self._root)



    class IFrame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pid = self._io.read_u1()
            self.ax25_info = self._io.read_bytes_full()


    class SsidMask(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ssid_mask = self._io.read_u1()

        @property
        def ssid(self):
            if hasattr(self, '_m_ssid'):
                return self._m_ssid if hasattr(self, '_m_ssid') else None

            self._m_ssid = ((self.ssid_mask & 15) >> 1)
            return self._m_ssid if hasattr(self, '_m_ssid') else None


    class ObcPacketT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            _on = self._parent.ccsds_header.packet_category
            if _on == 1:
                self.obc_packet = Picsat.ObcBeaconT(self._io, self, self._root)
            else:
                self.obc_packet = Picsat.DumpT(self._io, self, self._root)


    class DumpT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.payload = self._io.read_bytes_full()


    class Repeaters(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rpt_callsign_raw = Picsat.CallsignRaw(self._io, self, self._root)
            self.rpt_ssid_raw = Picsat.SsidMask(self._io, self, self._root)


    class Repeater(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rpt_instance = []
            i = 0
            while True:
                _ = Picsat.Repeaters(self._io, self, self._root)
                self.rpt_instance.append(_)
                if (_.rpt_ssid_raw.ssid_mask & 1) == 1:
                    break
                i += 1


    class CallsignRaw(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self._raw__raw_callsign_ror = self._io.read_bytes(6)
            self._raw_callsign_ror = KaitaiStream.process_rotate_left(self._raw__raw_callsign_ror, 8 - (1), 1)
            _io__raw_callsign_ror = KaitaiStream(BytesIO(self._raw_callsign_ror))
            self.callsign_ror = Picsat.Callsign(_io__raw_callsign_ror, self, self._root)


    class CcsdsSecondaryHeaderT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.days_since_ref = self._io.read_u2be()
            self.ms_since_today = self._io.read_u4be()


    class ObcBeaconT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.solar_panel5_error_flag = self._io.read_bits_int_be(1) != 0
            self.solar_panel4_error_flag = self._io.read_bits_int_be(1) != 0
            self.solar_panel3_error_flag = self._io.read_bits_int_be(1) != 0
            self.solar_panel2_error_flag = self._io.read_bits_int_be(1) != 0
            self.solar_panel1_error_flag = self._io.read_bits_int_be(1) != 0
            self.i_adcs_get_attitude_error = self._io.read_bits_int_be(1) != 0
            self.i_adcs_get_status_register_error = self._io.read_bits_int_be(1) != 0
            self.fram_enable_error_flag = self._io.read_bits_int_be(1) != 0
            self.ants_b_error_flag = self._io.read_bits_int_be(1) != 0
            self.ants_a_error_flag = self._io.read_bits_int_be(1) != 0
            self.trxvu_tx_error_flag = self._io.read_bits_int_be(1) != 0
            self.trxvu_rx_error_flag = self._io.read_bits_int_be(1) != 0
            self.obc_supervisor_error_flag = self._io.read_bits_int_be(1) != 0
            self.gom_eps_error_flag = self._io.read_bits_int_be(1) != 0
            self.ant1_undeployed_ants_b_status = self._io.read_bits_int_be(1) != 0
            self.ant1_timeout_ants_b_status = self._io.read_bits_int_be(1) != 0
            self.ant1_deploying_ants_b_status = self._io.read_bits_int_be(1) != 0
            self.ant2_undeployed_ants_b_status = self._io.read_bits_int_be(1) != 0
            self.ant2_timeout_ants_b_status = self._io.read_bits_int_be(1) != 0
            self.ant2_deploying_ants_b_status = self._io.read_bits_int_be(1) != 0
            self.ignore_flag_ants_b_status = self._io.read_bits_int_be(1) != 0
            self.ant3_undeployed_ants_b_status = self._io.read_bits_int_be(1) != 0
            self.ant3_timeout_ants_b_status = self._io.read_bits_int_be(1) != 0
            self.ant3_deploying_ants_b_status = self._io.read_bits_int_be(1) != 0
            self.ant4_undeployed_ants_b_status = self._io.read_bits_int_be(1) != 0
            self.ant4_timeout_ants_b_status = self._io.read_bits_int_be(1) != 0
            self.ant4_deploying_ants_b_status = self._io.read_bits_int_be(1) != 0
            self.armed_ants_b_status = self._io.read_bits_int_be(1) != 0
            self.ant1_undeployed_ants_a_status = self._io.read_bits_int_be(1) != 0
            self.ant1_timeout_ants_a_status = self._io.read_bits_int_be(1) != 0
            self.ant1_deploying_ants_a_status = self._io.read_bits_int_be(1) != 0
            self.ant2_undeployed_ants_a_status = self._io.read_bits_int_be(1) != 0
            self.ant2_timeout_ants_a_status = self._io.read_bits_int_be(1) != 0
            self.ant2_deploying_ants_a_status = self._io.read_bits_int_be(1) != 0
            self.ignore_flag_ants_a_status = self._io.read_bits_int_be(1) != 0
            self.ant3_undeployed_ants_a_status = self._io.read_bits_int_be(1) != 0
            self.ant3_timeout_ants_a_status = self._io.read_bits_int_be(1) != 0
            self.ant3_deploying_ants_a_status = self._io.read_bits_int_be(1) != 0
            self.ant4_undeployed_ants_a_status = self._io.read_bits_int_be(1) != 0
            self.ant4_timeout_ants_a_status = self._io.read_bits_int_be(1) != 0
            self.ant4_deploying_ants_a_status = self._io.read_bits_int_be(1) != 0
            self.armed_ants_a_status = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.solar_panel_temp5_zp = self._io.read_u2be()
            self.solar_panel_temp4_ym = self._io.read_u2be()
            self.solar_panel_temp3_yp = self._io.read_u2be()
            self.solar_panel_temp2_xm = self._io.read_u2be()
            self.solar_panel_temp1_xp = self._io.read_u2be()
            self.ants_temperature_side_b = self._io.read_u2be()
            self.ants_temperature_side_a = self._io.read_u2be()
            self.tx_trxvu_hk_current = self._io.read_u2be()
            self.tx_trxvu_hk_forwardpower = self._io.read_u2be()
            self.tx_trxvu_hk_tx_reflectedpower = self._io.read_u2be()
            self.tx_trxvu_hk_pa_temp = self._io.read_u2be()
            self.rx_trxvu_hk_pa_temp = self._io.read_u2be()
            self.rx_trxvu_hk_board_temp = self._io.read_u2be()
            self.eps_hk_temp_batt1 = self._io.read_s2be()
            self.eps_hk_temp_batt0 = self._io.read_s2be()
            self.eps_hk_batt_mode = self._io.read_u1()
            self.eps_h_kv_batt = self._io.read_u2be()
            self.eps_hk_boot_cause = self._io.read_u4be()
            self.n_reboots_eps = self._io.read_u4be()
            self.n_reboots_obc = self._io.read_u4be()
            self.quaternion1 = self._io.read_f4be()
            self.quaternion2 = self._io.read_f4be()
            self.quaternion3 = self._io.read_f4be()
            self.quaternion4 = self._io.read_f4be()
            self.angular_rate_x = self._io.read_f4be()
            self.angular_rate_y = self._io.read_f4be()
            self.angular_rate_z = self._io.read_f4be()
            self.gap_0 = self._io.read_bits_int_be(12)
            self.adcs_stat_flag_hl_op_tgt_cap = self._io.read_bits_int_be(1) != 0
            self.adcs_stat_flag_hl_op_tgt_track_fix_wgs84 = self._io.read_bits_int_be(1) != 0
            self.adcs_stat_flag_hl_op_tgt_track_nadir = self._io.read_bits_int_be(1) != 0
            self.adcs_stat_flag_hl_op_tgt_track = self._io.read_bits_int_be(1) != 0
            self.adcs_stat_flag_hl_op_tgt_track_const_v = self._io.read_bits_int_be(1) != 0
            self.adcs_stat_flag_hl_op_spin = self._io.read_bits_int_be(1) != 0
            self.gap_1 = self._io.read_bits_int_be(1) != 0
            self.adcs_stat_flag_hl_op_sunp = self._io.read_bits_int_be(1) != 0
            self.adcs_stat_flag_hl_op_detumbling = self._io.read_bits_int_be(1) != 0
            self.adcs_stat_flag_hl_op_measure = self._io.read_bits_int_be(1) != 0
            self.gap_2 = self._io.read_bits_int_be(5)
            self.adcs_stat_flag_datetime_valid = self._io.read_bits_int_be(1) != 0
            self.gap_3 = self._io.read_bits_int_be(1) != 0
            self.adcs_stat_flag_hl_op_safe = self._io.read_bits_int_be(1) != 0
            self.adcs_stat_flag_hl_op_idle = self._io.read_bits_int_be(1) != 0
            self.gap_4 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.up_time = self._io.read_u4be()
            self.last_fram_log_fun_err_code = self._io.read_s2be()
            self.last_fram_log_line_code = self._io.read_u2be()
            self.last_fram_log_file_crc_code = self._io.read_u4be()
            self.last_fram_log_counter = self._io.read_u2be()
            self.average_photon_count = self._io.read_u2be()
            self.sat_mode = self._io.read_u1()
            self.tc_sequence_count = self._io.read_u2be()






# This is a generated file! Please edit source .ksy file and use kaitai-struct-compiler to rebuild

from pkg_resources import parse_version
import kaitaistruct
from kaitaistruct import KaitaiStruct, KaitaiStream, BytesIO


if parse_version(kaitaistruct.__version__) < parse_version('0.9'):
    raise Exception("Incompatible Kaitai Struct Python API: 0.9 or later is required, but you have %s" % (kaitaistruct.__version__))

class Meznsat(KaitaiStruct):
    """:field dest_callsign: ax25_frame.ax25_header.dest_callsign_raw.callsign_ror.callsign
    :field src_callsign: ax25_frame.ax25_header.src_callsign_raw.callsign_ror.callsign
    :field src_ssid: ax25_frame.ax25_header.src_ssid_raw.ssid
    :field dest_ssid: ax25_frame.ax25_header.dest_ssid_raw.ssid
    :field rpt_callsign: ax25_frame.ax25_header.repeater.rpt_instance[0].rpt_callsign_raw.callsign_ror.callsign
    :field ctl: ax25_frame.ax25_header.ctl
    :field pid: ax25_frame.payload.pid
    :field frame_length: frame_length
    :field callsign: ax25_frame.payload.ax25_info.beacon_type.callsign
    :field satellite_mode: ax25_frame.payload.ax25_info.beacon_type.satellite_mode
    :field day_of_month: ax25_frame.payload.ax25_info.beacon_type.day_of_month
    :field day_of_week: ax25_frame.payload.ax25_info.beacon_type.day_of_week
    :field hour: ax25_frame.payload.ax25_info.beacon_type.hour
    :field minute: ax25_frame.payload.ax25_info.beacon_type.minute
    :field sec: ax25_frame.payload.ax25_info.beacon_type.sec
    :field obc_reset_count: ax25_frame.payload.ax25_info.beacon_type.obc_reset_count
    :field obc_temp: ax25_frame.payload.ax25_info.beacon_type.obc_temp
    :field vbatt: ax25_frame.payload.ax25_info.beacon_type.vbatt
    :field sys_current: ax25_frame.payload.ax25_info.beacon_type.sys_current
    :field batt_temp: ax25_frame.payload.ax25_info.beacon_type.batt_temp
    :field ext_batt1_temp: ax25_frame.payload.ax25_info.beacon_type.ext_batt1_temp
    :field ext_batt2_temp: ax25_frame.payload.ax25_info.beacon_type.ext_batt2_temp
    :field eps_reboots: ax25_frame.payload.ax25_info.beacon_type.eps_reboots
    :field receiver_current: ax25_frame.payload.ax25_info.beacon_type.receiver_current
    :field transmitter_current: ax25_frame.payload.ax25_info.beacon_type.transmitter_current
    :field pa_temp: ax25_frame.payload.ax25_info.beacon_type.pa_temp
    :field pa_current: ax25_frame.payload.ax25_info.beacon_type.pa_current
    :field adcs_run_mode: ax25_frame.payload.ax25_info.beacon_type.adcs_run_mode
    :field estimated_x_angular_rate: ax25_frame.payload.ax25_info.beacon_type.estimated_x_angular_rate
    :field estimated_y_angular_rate: ax25_frame.payload.ax25_info.beacon_type.estimated_y_angular_rate
    :field estimated_z_angular_rate: ax25_frame.payload.ax25_info.beacon_type.estimated_z_angular_rate
    :field estimated_q1: ax25_frame.payload.ax25_info.beacon_type.estimated_q1
    :field estimated_q2: ax25_frame.payload.ax25_info.beacon_type.estimated_q2
    :field estimated_q3: ax25_frame.payload.ax25_info.beacon_type.estimated_q3
    :field ant_temp: ax25_frame.payload.ax25_info.beacon_type.ant_temp
    :field minus_z_temp: ax25_frame.payload.ax25_info.beacon_type.minus_z_temp
    :field plus_z_temp: ax25_frame.payload.ax25_info.beacon_type.plus_z_temp
    :field minus_y_temp: ax25_frame.payload.ax25_info.beacon_type.minus_y_temp
    :field plus_y_temp: ax25_frame.payload.ax25_info.beacon_type.plus_y_temp
    :field minus_x_temp: ax25_frame.payload.ax25_info.beacon_type.minus_x_temp
    :field plus_x_temp: ax25_frame.payload.ax25_info.beacon_type.plus_x_temp
    :field message: ax25_frame.payload.ax25_info.beacon_type.message
    
    Attention: `rpt_callsign` cannot be accessed because `rpt_instance` is an
    array of unknown size at the beginning of the parsing process! Left an
    example in here.
    
    .. seealso::
       
    """
    def __init__(self, _io, _parent=None, _root=None):
        self._io = _io
        self._parent = _parent
        self._root = _root if _root else self
        self._read()

    def _read(self):
        self.ax25_frame = Meznsat.Ax25Frame(self._io, self, self._root)

    class Ax25Frame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ax25_header = Meznsat.Ax25Header(self._io, self, self._root)
            _on = (self.ax25_header.ctl & 19)
            if _on == 0:
                self.payload = Meznsat.IFrame(self._io, self, self._root)
            elif _on == 3:
                self.payload = Meznsat.UiFrame(self._io, self, self._root)
            elif _on == 19:
                self.payload = Meznsat.UiFrame(self._io, self, self._root)
            elif _on == 16:
                self.payload = Meznsat.IFrame(self._io, self, self._root)
            elif _on == 18:
                self.payload = Meznsat.IFrame(self._io, self, self._root)
            elif _on == 2:
                self.payload = Meznsat.IFrame(self._io, self, self._root)


    class Ax25Header(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.dest_callsign_raw = Meznsat.CallsignRaw(self._io, self, self._root)
            self.dest_ssid_raw = Meznsat.SsidMask(self._io, self, self._root)
            self.src_callsign_raw = Meznsat.CallsignRaw(self._io, self, self._root)
            self.src_ssid_raw = Meznsat.SsidMask(self._io, self, self._root)
            if (self.src_ssid_raw.ssid_mask & 1) == 0:
                self.repeater = Meznsat.Repeater(self._io, self, self._root)

            self.ctl = self._io.read_u1()


    class UiFrame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pid = self._io.read_u1()
            _on = self._parent.ax25_header.src_callsign_raw.callsign_ror.callsign
            if _on == u"A68MZ ":
                self._raw_ax25_info = self._io.read_bytes_full()
                _io__raw_ax25_info = KaitaiStream(BytesIO(self._raw_ax25_info))
                self.ax25_info = Meznsat.MeznsatPayload(_io__raw_ax25_info, self, self._root)
            else:
                self.ax25_info = self._io.read_bytes_full()


    class Callsign(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.callsign = (self._io.read_bytes(6)).decode(u"ASCII")


    class IFrame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pid = self._io.read_u1()
            self.ax25_info = self._io.read_bytes_full()


    class SsidMask(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ssid_mask = self._io.read_u1()

        @property
        def ssid(self):
            if hasattr(self, '_m_ssid'):
                return self._m_ssid if hasattr(self, '_m_ssid') else None

            self._m_ssid = ((self.ssid_mask & 15) >> 1)
            return self._m_ssid if hasattr(self, '_m_ssid') else None


    class Repeaters(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rpt_callsign_raw = Meznsat.CallsignRaw(self._io, self, self._root)
            self.rpt_ssid_raw = Meznsat.SsidMask(self._io, self, self._root)


    class Repeater(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rpt_instance = []
            i = 0
            while True:
                _ = Meznsat.Repeaters(self._io, self, self._root)
                self.rpt_instance.append(_)
                if (_.rpt_ssid_raw.ssid_mask & 1) == 1:
                    break
                i += 1


    class MeznsatTlm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.callsign = (self._io.read_bytes(7)).decode(u"utf-8")
            self.satellite_mode = self._io.read_u1()
            self.day_of_month = self._io.read_u1()
            self.day_of_week = self._io.read_u1()
            self.hour = self._io.read_u1()
            self.minute = self._io.read_u1()
            self.sec = self._io.read_u1()
            self.obc_reset_count = self._io.read_u4le()
            self.obc_temp = self._io.read_s2le()
            self.vbatt = self._io.read_u2le()
            self.sys_current = self._io.read_u2le()
            self.batt_temp = self._io.read_s2le()
            self.ext_batt1_temp = self._io.read_s2le()
            self.ext_batt2_temp = self._io.read_s2le()
            self.eps_reboots = self._io.read_u2le()
            self.receiver_current = self._io.read_u2le()
            self.transmitter_current = self._io.read_u2le()
            self.pa_temp = self._io.read_s2le()
            self.pa_current = self._io.read_u2le()
            self.adcs_run_mode = self._io.read_u1()
            self.estimated_x_angular_rate = self._io.read_s2le()
            self.estimated_y_angular_rate = self._io.read_s2le()
            self.estimated_z_angular_rate = self._io.read_s2le()
            self.estimated_q1 = self._io.read_u2le()
            self.estimated_q2 = self._io.read_u2le()
            self.estimated_q3 = self._io.read_u2le()
            self.ant_temp = self._io.read_s2le()
            self.minus_z_temp = self._io.read_s4le()
            self.plus_z_temp = self._io.read_s4le()
            self.minus_y_temp = self._io.read_s4le()
            self.plus_y_temp = self._io.read_s4le()
            self.minus_x_temp = self._io.read_s4le()
            self.plus_x_temp = self._io.read_s4le()


    class MeznsatPayload(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            _on = self._io.size()
            if _on == 78:
                self.beacon_type = Meznsat.MeznsatTlm(self._io, self, self._root)
            else:
                self.beacon_type = Meznsat.MeznsatGenericPacket(self._io, self, self._root)


    class CallsignRaw(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self._raw__raw_callsign_ror = self._io.read_bytes(6)
            self._raw_callsign_ror = KaitaiStream.process_rotate_left(self._raw__raw_callsign_ror, 8 - (1), 1)
            _io__raw_callsign_ror = KaitaiStream(BytesIO(self._raw_callsign_ror))
            self.callsign_ror = Meznsat.Callsign(_io__raw_callsign_ror, self, self._root)


    class MeznsatGenericPacket(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.message = (self._io.read_bytes_full()).decode(u"utf-8")


    @property
    def frame_length(self):
        if hasattr(self, '_m_frame_length'):
            return self._m_frame_length if hasattr(self, '_m_frame_length') else None

        self._m_frame_length = self._io.size()
        return self._m_frame_length if hasattr(self, '_m_frame_length') else None


